# ds-format

ds-format is an open source program, a Python package and a storage format
which provides an interface for reading and writing NetCDF files, as well as its
own optional data file format. The data format and interface are a
simpler alternative to other more complex interfaces and formats, while
supporting most of the same essential functions.

Please see [ds-format.peterkuma.net](https://ds-format.peterkuma.net)
for more information.

The documentation is also available in the [docs](docs/) directory as a
[Jekyll](https://jekyllrb.com) website.
